"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** 构建一个从指定的 caseObj 中选择 reducer 的 reducer */
function buildCaseObjReducer(state, caseObj) {
    return function (s, ac) {
        if (s === void 0) { s = state; }
        var caseReducer = caseObj[ac.type];
        if (!caseReducer) {
            // 没有 reducer 匹配 > 不处理state;
            return s;
        }
        return caseReducer(s, ac.payload);
    };
}
/**
 * 将一批 action 处理为对数据 state 的归约.
 * @param state 初始的 state
 * @param actionsMapper 每个action的处理函数;
 */
exports.reduceActions = function (state, actionsMapper) { return function (reducersMapper) {
    var caseObj = {};
    // 构造每个 action 对应的 reducer.
    Object.keys(actionsMapper).forEach(function (actionKey) {
        var oneActionCreator = actionsMapper[actionKey];
        var oneActionHandler = reducersMapper[actionKey];
        if (typeof oneActionHandler === "function") {
            caseObj[oneActionCreator.toString()] = oneActionHandler;
        }
    });
    return buildCaseObjReducer(state, caseObj);
}; };
